<?php 
/*

WP_Malscart_Options_Page

class to display the settings page


*/

class WP_Malscart_Options_Page {

	public function initialize( ) {

		self::add_admin_page();

	}

	// add the admin options page
	private function add_admin_page() {

		$pageName = add_options_page( 
										 WP_Malscart::PLUGIN_TITLE, 
										 WP_Malscart::PLUGIN_TITLE, 
										 'manage_options', 
										 WP_Malscart::$OPTIONS_PAGE_NAME, 
										 array( 'WP_Malscart_Options_Page', 'options_page' ) 
										 );

		//add_action( "admin_head-" . $pageName, array( "WP_Malscart_Options_Page", "admin_header" ), 12 );
		
		if ( self::on_options_page() ) {

			add_action( "in_admin_footer", array( 'WP_Malscart_Options_Page', "admin_footer" ) );
		
			add_action( 'admin_print_scripts-' . $pageName, array( 'WP_Malscart_Options_Page', 'scripts' ) );

		}

	}


	// adds some info to the admin options page footer	
	public function admin_footer() {

		$plugin_data = WP_Malscart::plugin_data();
		printf( '%1$s plugin | Version %2$s<br />', $plugin_data['Name'], $plugin_data['Version'] );

	}
	
	// add some stuff to the admin options page header	
	public function admin_header() {

		//echo '<link href="' . WP_Malscart::$PLUGIN_URL . '/'.WP_Malscart::PLUGIN_NAME.'.css" rel="stylesheet" type="text/css" />';
		wp_enqueue_style( WP_Malscart::PLUGIN_NAME.'-options', WP_Malscart::$PLUGIN_URL . '/'.WP_Malscart::PLUGIN_NAME.'.css' );
		
		wp_enqueue_style( WP_Malscart::PLUGIN_NAME.'-buttons', WP_Malscart::$PLUGIN_URL . '/'.WP_Malscart::PLUGIN_NAME.'-buttons.css' );

	}
	
	/* jQuery Tabs */
	public function scripts() {
		
		wp_enqueue_script( 'jquery-ui-tabs' );
		
		wp_enqueue_script( 'wp-malscart-js' , WP_Malscart::$PLUGIN_URL . '/js/wp-malscart-admin.js' );
		
	}

	// check to see that we're on the plugin options page
	public function on_options_page() {
		
		//return false !== stripos( WP_Malscart::$OPTIONS_PAGE_NAME, $_GET[ 'page' ] );
		
		return WP_Malscart::$ON_OPTIONS_PAGE;

	}
	
/**
* this function is called with each section heading
* and outputs the help page for that section
*/
	public function print_section( $args ) {
		
		extract( $args );
		
		//error_log( __METHOD__.' args='.print_r( $args, true ));
		
		// WP will print the title itself until I can figure out how to stop it
		// echo '<h3 class="title">'.$title.'</h3>';
		
		if ( $id == 'help' ) echo self::help_page();
		
		if ( !empty( $desc ) ) echo "\r".'<p>'.$desc.'</p>'; // this won't happen until I flush out the section definition array with more fields
		
	}

	// display the admin options page
	public function options_page() {
		
		global $WP_Malscart;
?>
		<div class="wrap">
			<div class="icon32" id="icon-options-<?php echo WP_Malscart::PLUGIN_NAME ?>"><img src="<?php echo WP_Malscart::$PLUGIN_URL.'/wpmalscart-logo-image-36x36.png' ?>"><br></div>
			<h2><?php echo WP_Malscart::PLUGIN_TITLE?></h2>
			<form action="options.php" method="post">
			
			
			<?php settings_fields( WP_Malscart::$OPTIONS_SETTINGS ); ?>
			
				<div class="ui-tabs">
					<ul class="ui-tabs-nav">
				
			<?php foreach ( $WP_Malscart->sections as $section )
						echo '<li><a href="#' . strtolower( str_replace( ' ', '_', $section ) ) . '">' . $section . '</a></li>'; ?>
								
					</ul>
			
			<?php do_settings_sections(  WP_Malscart::$OPTIONS_PAGE_NAME ); ?>
			
				</div>
				<p class="submit"><input name="Submit" type="submit" value="<?php esc_attr_e('Save Changes'); ?>" class="button-primary"  /></p>
			</form>
			<script type="text/javascript">
				jQuery(document).ready(function($) {
						var wrapped = $(".wrap .ui-tabs>h3").wrap("<div class=\"ui-tabs-panel\">");
						wrapped.each(function() {
							$(this).parent().append($(this).parent().nextUntil("div.ui-tabs-panel"));
						});
						$(".ui-tabs-panel").each(function(index) {
							var str = $(this).children("h3").text().replace(/\s/g, "_");
							$(this).attr("id", str.toLowerCase());
							if (index > 0)
								$(this).addClass("ui-tabs-hide");
						});
						$(".ui-tabs").tabs({ fx: { opacity: "toggle", duration: "fast" } });
						$(".wrap h3, .wrap table").show();
						if ($.browser.mozilla)
         			$("form").attr("autocomplete", "off");
				});
			</script>
		</div>
<?php 

	} // options_page fn

	private function print_error_series( ) {
		
		//global $wp_settings_errors;
		//global $WP_Malscart;
		
		//error_log( __METHOD__.'v='.(WP_Malscart::$is_update?'true':'false').' options array:'.print_r( get_option( WP_Malscart::$OPTIONS_SETTINGS ), true ));
		
		if ( ! WP_Malscart::$is_update  ) {

			WP_Malscart::options_validate( get_option( WP_Malscart::$OPTIONS_SETTINGS ) );

		}
		
		$errors = get_settings_errors();
		
		//error_log( __METHOD__.' errors='.print_r( $errors, true ) );
		
		$html = array();
		
		if( count( $errors ) ) {
		
			$css_selectors = array();
			$css_pattern = '.form-table input[id="%s"] ';
			
			
			$error_divs = array();
			$error_pattern = '<div class="'.WP_Malscart::PLUGIN_NAME.' %3$s settings-%3$s" id="setting-%3$s-%1$s"><p><strong>%2$s</strong></p></div>';
			
			foreach( $errors as $error ) {

				$css_selectors[] = sprintf( $css_pattern, $error[ 'code' ] );

				$error_divs[] = sprintf( $error_pattern, $error[ 'code' ], $error[ 'message' ], $error[ 'type' ] );

			}
			
			
			// print the field highlight css
			if ( $error[ 'type' ] == 'error' ) $html[] = '<style type="text/css" >'.implode( $css_selectors, ',' ).'{ background-color: #FFEBE8; border-color: #CC0000; }</style>';
			
			// print the error messages
			$html[] = "\r".implode( $error_divs, "\r" );
			
			self::print_html( $html );
			
		}
		
		
	}
	
	public function display_errors( ) {

		// we only do this on the plugins own options page
		if ( WP_Malscart::$ON_OPTIONS_PAGE ) self::print_error_series( );
	
	}
	
	
	public function display_setting_field( Array $field_args ) {
		
		extract( $field_args );
		
		$options = get_option( WP_Malscart::$OPTIONS_SETTINGS );
		
		if ( ! isset( $options[$id] ) && $type != 'checkbox' )
			$options[$id] = $value; // if it's not set, set the value of the field to the default
		elseif ( ! isset( $options[$id] ) )
			$options[$id] = 0; // checkboxes need this to be zero
		
		/*if ( $class != '' )
			$field_args[ 'class' ] = ' class="' . $class . '"';*/
			
		switch ( $type ) {
			
			case 'text':
				self::admin_text_field( $field_args );
				break;
				
			case 'radio':
				self::admin_radio_field( $field_args );
				break;
				
			case 'dropdown':
				self::admin_dropdown_field( $field_args );
				break;
				
			case 'button_style':
				self::button_style_field( $field_args );
				break;
				
			case 'header':
				echo self::settings_header( $field_args );
				break;
			
			default:
				$field_args[ 'tag' ] = $field_args[ 'type' ];
				WP_Malscart_HTML::build_tag( $field_args );
				
		}
		
	}


/*   settings page fields   */

	public function admin_text_field( $args ) {
		
		//error_log( __METHOD__.' args:'.print_r( $args, true ));
		extract( $args );
		$options = get_option( WP_Malscart::$OPTIONS_SETTINGS );
		echo WP_Malscart_HTML::text_field( array(
										'name' 	=> WP_Malscart::$OPTIONS_SETTINGS.'['.$id.']',
										'value'	=> esc_attr( $options[$id] ),
										'id'		=> $id,
										'desc'=> $desc,
										'class'	=> $class
										) );
	}
	
	public function admin_radio_field( $args ) {
		extract( $args ); // id, $items = array( 'label'=>'value' )
		$options = get_option( WP_Malscart::$OPTIONS_SETTINGS );
		echo WP_Malscart_HTML::radio_field( array(
											'name'	=> WP_Malscart::$OPTIONS_SETTINGS.'['.$id.']',
											'items'	=> $items,
											'value'	=> esc_attr( $options[$id] )
											) );
	}

	public function  admin_dropdown_field( $args ) {
		extract( $args ); // id, $items = array( 'label'=>'value' )
		$options = get_option( self::$OPTIONS_SETTINGS );
		echo WP_Malscart_HTML::dropdown_field( array(
											'name'	=> WP_Malscart::$OPTIONS_SETTINGS.'['.$id.']',
											'items'	=> $items,
											'value'	=> esc_attr( $options[$id] ),
											'id'		=> $id
											) );
	}

	public function settings_header( $args ) {
		extract( $args );
		echo WP_Malscart_HTML::build_tag( array(
											'tag'		=> 'h4',
											'text'	=> $title
											) );
		if ( ! empty( $desc ) )
			echo WP_Malscart_HTML::build_tag( array(
											'tag'		=> 'p',
											'text'	=> $desc
											) );
	}
	
	// prints all the button styles to choose from
	public function button_style_field( $args ) {

		extract( $args );
		$options = get_option( WP_Malscart::$OPTIONS_SETTINGS );

		$html = array();
		
		$html[] = '<div class="buy-button-styles">';
		
		foreach ( $items as $label => $value ) {
			$html[] =  '<div>';// container for each style
			$html[] =  WP_Malscart_HTML::radio_field( array(
												'name'	=> WP_Malscart::$OPTIONS_SETTINGS.'['.$id.']',
												'items'	=> array( $label => $value ),
												'value'	=> esc_attr( $options[$id] )
												) ); // creates the radio button
			
			// output the button itself to preview it's appearance ( unless we use an iframe, this will never look exactly like it will on the site. ) 
			$html[] = WP_Malscart_HTML::buy_button_html( array( 
												'demo'			=> true, // this supresses form actions for display purposes
												'product[]' 	=> $options[ 'test_product' ], 
												'price' 		=> $options[ 'test_price' ],
												'button_width'	=> $options[ 'button_width' ],
												'button_style' 		=> $value
												)  ). '</div>';
		}
		
		$html[] = '</div>';
		
		self::print_html( $html );

	}
	
	// outputs a help page
	private function help_page() {
		
		$plugin_data = WP_Malscart::plugin_data();
		
		ob_start();
?>
		<div class="read_column">
		<h4><?php echo WP_Malscart::PLUGIN_TITLE?></h4>
<p>version: <?php echo $plugin_data[ 'Version' ]?></p>
<p>This wordpress plugin is the first development phase of a full-featured WordPress online commerce application using the third-party cart service <a href="http://mals-e.com">Mal&#8217;s Cart (mals-e.com)</a>. Version 1 provides simple product buy buttons as a shortcode to include in your WordPress pages and posts. Clicking the button sends the customer to the shopping cart and adds the product to the cart.</p>
<p>This plugin represents what I think is the easiest and most straightforward way to begin selling products to your site&#8217;s visitors. It is a great way to get started with online commerce. It&#8217;s also designed to visually match the theme of your website without a lot of customization.</p>

<h3>Installation and Use</h3>
<p>Install the plugin in one of two ways&#8211;either automatically using the WordPress plugin installer, or by downloading the plugin. The best way is automatically: On your WordPress site, go to &#8220;Add New&#8221; under the plugin menu. Search for &#8220;WP Malscart&#8221; and install and activate using the link to the plugin.</p>
<p>If you use the download, download and unzip the file on your computer then upload the whole &#8220;wp-malscart&#8221; folder to the /wp-content/plugins/ directory. Then go to the plugins page in your WordPress admin and activate the plugin. You&#8217;ll find the settings page under the &#8220;Settings&#8221; menu.</p>

<p>To use this plugin, <strong>you must first establish an account with Mal&#8217;s Cart.</strong> Your username (actually a number) and the cart server domain goes into the General Settings tab of this plugin. You will be provided with this information when you register your account at mals-e.com.</p>
<h4>Using the Shortcodes</h4>
<p>To use the shortcode, put something like this in your page or post:</p>
<p><code>[buy_button product=&quot;The Product Name&quot; price=&quot;25.00&quot;]</code></p>

<p>The two arguments, &#8216;product&#8217; and &#8216;price&#8217; are required. In addition to these two, you can set up a series of options for the product, such as color or size. For example:</p>
<p><code>[buy_button product=&quot;Test Product&quot; price=&quot;10.00&quot; color=&quot;Product Color:Red,Light Blue,Hunter&#039;s Green&quot; ]</code></p>

<p>To add product options, add an argument to the shortcode with any name you want (though it can&#8217;t be &#8216;product&#8217; or &#8216;price&#8217; for obvious reasons and no spaces or punctuation) and then in quotes the display name of the option and then all the option names with commas in between each one. As you can see, things like space and some punctuation are allowed here.</p>
<p>In this version of the plugin, these &#8216;product attributes&#8217; can&#8217;t affect the price. They are really just a way to put this extra information into the order so you know which one to send. When we get to version 2, we will add a <em>product post type</em> that will allow for much more complex pricing schemes as well as product management and display possibilities.</p>

<h4>Setting Up Mal&#8217;s Cart</h4>
<p>Properly setting up the cart can be a little complicated, and I suggest you give this aspect of setting up your store a lot of attention and testing. Getting it wrong can be a source of stress once you begin selling, so work through all the details before you let the customers in. Just a piece of advice from someone who has been there!</p>
<p>Mal&#8217;s Cart has a very active and helpful <a href="https://www.mals-e.com/forum.php">community</a>, so you won&#8217;t be without help in your questions.</p>
<h4>Help and Support</h4>
<p>Questions about the plugin can be emailed to me, Roland, at <span class='email' rel='xnau.com-webdesign'>my email</span>. If you need more extensive help setting up your store (as I have done for many others) I will want to invoice you for my time, but don&#8217;t think I&#8217;m going to break your bank there. I specialize in small-scale operations with limited budgets (not that my bookkeeper thinks this is smart!) and I know you mostly just want a little help and then be on your way.</p>

<p>Time permitting, I can also provide full-service online commerce development.</p>
<h3>Future Development</h3>
<p>The development plan for the plugin is as follows:</p>
<ol>
<li>single-product buy button shortcodes</li>
<li>product post type, multiple product ordering, product management and display</li>
<li>advanced product attributes, images, pricing</li>
<li>sales, discounts and specials, related products</li>
<li>integrate with users, user role discounts (wholesale/retail)</li>

<li>local sales records</li>
<li>integrate cart screens with site</li>
</ol>
<p>Some of the more advanced features will only be included in a premium version of the plugin.</p>
<h3>Release History</h3>
<h4>0.6</h4>
<ul>
<li>initial release</li>
<li>buy button shortcodes</li>
<li>internationalization</li>

<li>admin settings page</li>
<li>help page</li>
</ul>
<h4>0.6.2</h4>
<ul>
	<li> fixed several bugs due to directory name change	</li>
</ul>
<h4>0.7</h4>
<ul>
	<li>refactored settings validation code</li>
	<li>all plugin settings are now held in a class object</li>
	<li>added initial setup notification</li>
</ul>
<h3>Acknowledgements</h3>
<p>This project would not have been possible without knowledge gained from the following authors and sites:</p>
<ul>
<li><a href="http://alisothegeek.com" rel="author">Aliso the Geek</a></li>
<li><a href="http://beerpla.net/">Beer Planet </a></li>
<li><a href="http://w3prodigy.com/">Jay Fortner</a></li>
<li><a href="http://www.obenlands.de/">Obenlands</a></li>

<li><a href="http://planetozh.com/blog/">planetOzh</a></li>
<li><a href="http://codex.wordpress.org">WordPress Codex</a></li>
</ul>
<p>and many others who have generously offered their expertise to the community.</p>
		</div>
<?php

		return ob_get_clean(); //echo apply_filters( 'the_content', ob_get_clean() );

	}
	
	// outputs an array or string	
	private function print_html( $html ) {
		
		if ( ! count( $html ) ) $html = array( (string) $html );
		
		echo implode( "\r", $html );
		
	}
	
	public function errors_exist() {
		
		$errors = get_settings_errors();
		
		return	empty( $errors ) ? false : true;
	
	}
		
	
	
	
} // options page class definition
?>
