<?php
/**
 * this class defines all the plugin's settings and several untility methods to interact with it
 *
 * each setting has a collection of attributes including the name, slug, default values, validation regex 
 * field type, validation status, and settings section membership
 * any new settings are added to the plugin are added to the $settings_data_sets array
 * 
 * PHP version 5.1.2
 *
 *
 * @package			WP_Malscart
 * @author			Roland Barker <webdesign@xnau.com>
 * @copyright		2011 xnau webdesign
 * @version			Release: @package_version@
 * @license			GPL2
 * @link				http://xnau.com/wp-malscart
 * @since				File available since Release 0.7
 */

class WP_Malscart_Settings {

	/**
	 * this array contains all instantiated settings values, status, error messages, etc.
	 *
	 * @param array $settings
	 * 	id			string	slug string for the setting
	 *	desc		string	This is a default description
	 *	value		string	default value for the setting
	 *	type		string	the type of field for the setting; text, option, radio, textarea
	 *	section	string	the section the setting is part of
	 *	items		array		id => title pairs for settings options list
	 *	class		string	if we want to add a CSS class to the element, we can put it here
	 *	status	string	validation status; can be 'empty','invalid','valid'
	 *	err_msg	array		error messages
	 *		empty		error message for an empty field					
	 *		invalid	error message for an invalid field
	 *	regex		string	if validation is needed, use this regex			
	 */
	private $settings = array();
	
	/**
	 * this array defines all settings values, status, error messages, etc.
	 *
	 * @param array $settings
	 * 	id			string	slug string for the setting
	 *	desc		string	This is a default description
	 *	value		string	default value for the setting
	 *	type		string	the type of field for the setting; text, option, radio, textarea
	 *	section	string	the section the setting is part of
	 *	items		array		id => title pairs for settings options list
	 *	class		string	if we want to add a CSS class to the element, we can put it here
	 *	status	string	validation status; can be 'empty','invalid','valid'
	 *	err_msg	array		error messages
	 *		empty		error message for an empty field					
	 *		invalid	error message for an invalid field
	 *	regex		string	if validation is needed, use this regex		
	 *
	 * @static
	 */
	private static $settings_data_sets = array();

	public function __construct() {
		
		/*
		 * this array holds all the data sets for each setting
		 */
		self::$settings_data_sets = array(

			'cart_server' => array( 
																										
																							'title'			=> 'Cart Server', 
																							'desc'			=> 'The server name for your cart; something like "http://ww1.aitsafe.com"', 
																							'type'			=> 'text',
																							'value'			=> '',
																							'section'		=> 'main_options',
																							/*'status'		=> 'empty',*/
																							'err_msg'		=> array(
																																		'empty' 		=> 'The Cart URL is required',
																																		'invalid'		=> 'Check that the Cart URL is complete and correct, including the protocol (http://)',
																																		),
																							// this breaks the value into pieces and keeps the important part
																							'regex'			=> '|^(?P<protocol>http(?P<secure_flag>s)?://)(?P<subdomain>[a-z0-9-]{3})\.'.ltrim( WP_Malscart::$malscart_cart_domain, '.' ).'(?P<path>/.*)?$|',
				
			),
	
			'cust_id' => array( 
																								
																							'title'			=> "Mal's E-Commerce Username", 
																							'desc'			=> 'This is your 8-digit username', 
																							'type'			=> 'text',
																							'value'			=> '',
																							'section'		=> 'main_options',
																							/*'status'		=> 'empty',*/
																							'err_msg'		=> array(
																																		'empty' 		=> "Your Mal's E-Commerce Username is required",
																																		'invalid'		=> "Your Mal's E-Commerce Username seems to be incorrect",
																																		),
																							'regex'			=> '|^([0-9]{8})$|',
				
			),
			
			'button_CSS' => array( 
																																												 
																							'title'			=> "Use plugin CSS?", 
																							'desc'			=> '', 
																							'type'			=> 'radio',
																							'value'			=> 1,
																							'section'		=> 'buy_button_options', 
																							'items' 			=> array( 
																																		__('Yes (plugin CSS will style buy buttons)', WP_Malscart::PLUGIN_NAME ) => 1, 
																																		__('No (buttons will be styled by theme CSS)', WP_Malscart::PLUGIN_NAME ) => 0
																																		),
				
			),
	
			'button_width' => array( 
																										
																							'title'			=> 'Width', 
																							'desc'			=> 'the default width of the box containing the button', 
																							'type'			=> 'text',
																							'value'			=> '150',
																							'section'		=> 'buy_button_options',
																							'err_msg'		=> array(
																																		'empty' 		=> '',
																																		'invalid'		=> 'Button width needs to be a number (for pixels) or a number with a CSS unit',
																																		),
																							'regex'			=> "#([0-9\.]+)(px|em|pt|%|ex)?#",
			),
	
			'selector_preference' => array( 
																														
																							'title'			=> "Which selector for product options?", 
																							'desc'			=> '', 
																							'type'			=> 'radio',
																							'value'			=> 'radio',
																							'section'		=> 'buy_button_options', 
																							'items' 			=> array( 
																													__('Radio Buttons (such as these)', WP_Malscart::PLUGIN_NAME ) => 'radio', 
																													__('Pull-down List (best for a large number of choices)', WP_Malscart::PLUGIN_NAME ) => 'select'
																												),
				
			),
	
			'button_text' => array(
																																													
																							'title'			=> 'Buy Button Label', 
																							'desc'			=> 'the default text that will appear on buy buttons', 
																							'type'			=> 'text',
																							'value'			=> 'Add to Cart',
																							'section'		=> 'buy_button_options',
																							'class'			=> 'special-text'
			),
			
	
			'test_product' => array( 
																										 
																							'title'			=> "Test Product Name", 
																							'desc'			=> '', 
																							'type'			=> 'text',
																							'value'			=> 'Test Product',
																							'section'		=> 'buy_button_options'
			),
			
	
			'test_price' => array(
																									 
																							'title'			=> 'Test Product Price', 
																							'desc'			=> '', 
																							'type'			=> 'text',
																							'value'			=> '25.00',
																							'section'		=> 'buy_button_options'
				
			),
	
			'button_style' => array( 
																																													 
																							'title'			=> 'Select Button Style', 
																							'desc'			=> 'Select a base style for the buy button shorcode', 
																							'type'			=> 'button_style',
																							'value'			=> 1,
																							'section'		=> 'buy_button_options', 
																							'items' 			=> array( 
																													__('Simple', WP_Malscart::PLUGIN_NAME ) => 1,
																													__('Product and price', WP_Malscart::PLUGIN_NAME ) => 2
																												)
				
			),
		);
		
		$this->load_settings();

	}


	/**
	* builds the settings object
	*
	* cycles through the static definition array, merging defaults into missing fields and setting the 'id' field
	*
	* @return NULL
	*
	*/
	private function load_settings() {

		foreach ( self::$settings_data_sets as $setting => $setting_data ) {
			
			$setting_data[ 'id' ] = $setting;
			
			$this->settings[ $setting ] = wp_parse_args( $setting_data, WP_Malscart::$setting_defaults );
			
		}

	} // load_settings
	
	/**
	 * gets the all the data sets
	 */
	public function get_all() {
		
		return $this->settings;
		
	}
	
	/**
	 * gets the data set for a setting
	 */
	public function get( $setting ) {
		
		return $this->settings[ $setting ];
		
	}
	
	/**
	 * gets the status of a setting
	 */
	public function get_status( $setting ) {
		
		return $this->get_single( $setting, 'status' );
		
	}
	
	/**
	 * gets a single data value of a setting
	 */
	public function get_single( $setting, $attribute ) {
		
		return isset( $this->settings[ $setting ][ $attribute ] ) ? $this->settings[ $setting ][ $attribute ] : false;
		
	}
	
	/**
	 * set a data value for a setting
	 */
	public function set_single( $setting, $attribute, $value ) {
		
		 // we may want to validate the value
		 $this->settings[ $setting ][ $attribute ] = $value;
		 
		 return true;
		 
	}
	
	/**
	 * set a data value for a setting
	 */
	public function set_status( $setting, $value ) {
		
		 // validate the input
		 if ( in_array( strtolower( $value ), array( 'valid', 'invalid', 'empty' ) ) ) {
		 
		 	$this->settings[ $setting ][ 'status' ] = strtolower( $value );
		 
		 	return true;
			
		 } else {
			 
			 return false;
			 
		 }
		 
	}
	
	/**
	 * returns a special-case error message for the plugin's initial state
	 * 
	 */
	public function get_initial_error() {
		
		return array(
						
							'err_msg' => array(
																 'empty' => "The Cart Server and Mal's E-Commerce Username must be set before you can use this plugin"
																 ),
							
							'id' => 'initial_state',
							
							'status' => 'empty',
							
							'title' => 'Initial State',
							
							);
	}

} // class
